@@ -9,6 +9,7 @@ macro_rules! define_affine2_struct {
     ($affine2:ident, $matrix:ident, $column:ident) => {
         /// A 2D affine transform, which can represent translation, rotation, scaling and shear.
         #[derive(Copy, Clone)]
+        #[repr(C)]
         pub struct $affine2 {
             pub matrix2: $matrix,
             pub translation: $column,
@@ -36,6 +37,12 @@ macro_rules! impl_affine2_methods {
                 translation: $column::ZERO,
             };
 
+            /// All NAN:s.
+            pub const NAN: Self = Self {
+                matrix2: $matrix::NAN,
+                translation: $column::NAN,
+            };
+
             /// Creates an affine transform from three column vectors.
             #[inline(always)]
             pub fn from_cols(x_axis: $column, y_axis: $column, z_axis: $column) -> Self {
@@ -199,8 +206,8 @@ macro_rules! impl_affine2_methods {
             #[inline]
             pub fn from_mat3(m: $mat3) -> Self {
                 Self {
-                    matrix2: $matrix::from_cols(m.x_axis.into(), m.y_axis.into()),
-                    translation: m.z_axis.into(),
+                    matrix2: $matrix::from_cols($vec2(m.x_axis.0.into()), $vec2(m.y_axis.0.into())),
+                    translation: $vec2(m.z_axis.0.into()),
                 }
             }
 
@@ -254,6 +261,7 @@ macro_rules! impl_affine2_methods {
             /// Return the inverse of this transform.
             ///
             /// Note that if the transform is not invertible the result will be invalid.
+            #[must_use]
             #[inline]
             pub fn inverse(&self) -> Self {
                 let matrix2 = self.matrix2.inverse();
@@ -302,7 +310,7 @@ macro_rules! impl_affine2_traits {
 
         #[cfg(not(target_arch = "spirv"))]
         impl core::fmt::Debug for $affine2 {
-            fn fmt(&self, fmt: &mut core::fmt::Formatter) -> core::fmt::Result {
+            fn fmt(&self, fmt: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
                 fmt.debug_struct(stringify!($affine2))
                     .field("matrix2", &self.matrix2)
                     .field("translation", &self.translation)
@@ -312,7 +320,7 @@ macro_rules! impl_affine2_traits {
 
         #[cfg(not(target_arch = "spirv"))]
         impl core::fmt::Display for $affine2 {
-            fn fmt(&self, f: &mut core::fmt::Formatter) -> core::fmt::Result {
+            fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
                 write!(f, "[{}, {}, {}]", self.x_axis, self.y_axis, self.z_axis)
             }
         }
@@ -484,9 +492,15 @@ impl_affine2_traits!(
     DerefTargetF64
 );
 
-#[cfg(any(feature = "scalar-math", target_arch = "spriv"))]
+#[cfg(all(
+    not(feature = "cuda"),
+    any(feature = "scalar-math", target_arch = "spriv")
+))]
 mod const_test_affine2 {
-    const_assert_eq!(4, core::mem::align_of::<super::Affine2>());
+    const_assert_eq!(
+        core::mem::align_of::<super::Vec2>(),
+        core::mem::align_of::<super::Affine2>()
+    );
     const_assert_eq!(24, core::mem::size_of::<super::Affine2>());
 }
 
@@ -497,6 +511,9 @@ mod const_test_affine2 {
 }
 
 mod const_test_daffine2 {
-    const_assert_eq!(8, core::mem::align_of::<super::DAffine2>());
+    const_assert_eq!(
+        core::mem::align_of::<super::DVec2>(),
+        core::mem::align_of::<super::DAffine2>()
+    );
     const_assert_eq!(48, core::mem::size_of::<super::DAffine2>());
 }
