@@ -6,7 +6,6 @@ use core::arch::x86::*;
 use core::arch::x86_64::*;
 
 use super::float::*;
-use crate::const_m128;
 use crate::core::{
     storage::{Align16, XY, XYZ, XYZW},
     traits::{scalar::*, vector::*},
@@ -14,7 +13,7 @@ use crate::core::{
 use core::mem::MaybeUninit;
 
 impl MaskVectorConst for __m128 {
-    const FALSE: __m128 = const_m128!([0.0; 4]);
+    const FALSE: __m128 = const_f32x4!([0.0; 4]);
 }
 
 impl MaskVector for __m128 {
@@ -159,21 +158,25 @@ unsafe fn dot4_in_x(lhs: __m128, rhs: __m128) -> __m128 {
 }
 
 impl VectorConst for __m128 {
-    const ZERO: __m128 = const_m128!([0.0; 4]);
-    const ONE: __m128 = const_m128!([1.0; 4]);
+    const ZERO: __m128 = const_f32x4!([0.0; 4]);
+    const ONE: __m128 = const_f32x4!([1.0; 4]);
 }
 
 impl Vector3Const for __m128 {
-    const X: __m128 = const_m128!([1.0, 0.0, 0.0, 0.0]);
-    const Y: __m128 = const_m128!([0.0, 1.0, 0.0, 0.0]);
-    const Z: __m128 = const_m128!([0.0, 0.0, 1.0, 0.0]);
+    const X: __m128 = const_f32x4!([1.0, 0.0, 0.0, 0.0]);
+    const Y: __m128 = const_f32x4!([0.0, 1.0, 0.0, 0.0]);
+    const Z: __m128 = const_f32x4!([0.0, 0.0, 1.0, 0.0]);
 }
 
 impl Vector4Const for __m128 {
-    const X: __m128 = const_m128!([1.0, 0.0, 0.0, 0.0]);
-    const Y: __m128 = const_m128!([0.0, 1.0, 0.0, 0.0]);
-    const Z: __m128 = const_m128!([0.0, 0.0, 1.0, 0.0]);
-    const W: __m128 = const_m128!([0.0, 0.0, 0.0, 1.0]);
+    const X: __m128 = const_f32x4!([1.0, 0.0, 0.0, 0.0]);
+    const Y: __m128 = const_f32x4!([0.0, 1.0, 0.0, 0.0]);
+    const Z: __m128 = const_f32x4!([0.0, 0.0, 1.0, 0.0]);
+    const W: __m128 = const_f32x4!([0.0, 0.0, 0.0, 1.0]);
+}
+
+impl NanConstEx for __m128 {
+    const NAN: __m128 = const_f32x4!([f32::NAN; 4]);
 }
 
 impl Vector<f32> for __m128 {
@@ -244,6 +247,16 @@ impl Vector<f32> for __m128 {
         unsafe { _mm_sub_ps(self, other) }
     }
 
+    #[inline(always)]
+    fn add_scalar(self, other: f32) -> Self {
+        unsafe { _mm_add_ps(self, _mm_set_ps1(other)) }
+    }
+
+    #[inline(always)]
+    fn sub_scalar(self, other: f32) -> Self {
+        unsafe { _mm_sub_ps(self, _mm_set_ps1(other)) }
+    }
+
     #[inline(always)]
     fn mul_scalar(self, other: f32) -> Self {
         unsafe { _mm_mul_ps(self, _mm_set_ps1(other)) }
@@ -254,6 +267,19 @@ impl Vector<f32> for __m128 {
         unsafe { _mm_div_ps(self, _mm_set_ps1(other)) }
     }
 
+    #[inline(always)]
+    fn rem(self, other: Self) -> Self {
+        unsafe {
+            let n = m128_floor(_mm_div_ps(self, other));
+            _mm_sub_ps(self, _mm_mul_ps(n, other))
+        }
+    }
+
+    #[inline(always)]
+    fn rem_scalar(self, other: f32) -> Self {
+        unsafe { self.rem(_mm_set1_ps(other)) }
+    }
+
     #[inline(always)]
     fn min(self, other: Self) -> Self {
         unsafe { _mm_min_ps(self, other) }
@@ -316,19 +342,19 @@ impl Vector3<f32> for __m128 {
 
     #[inline(always)]
     fn as_ref_xyz(&self) -> &XYZ<f32> {
-        unsafe { &*(self as *const Self as *const XYZ<f32>) }
+        unsafe { &*(self as *const Self).cast() }
     }
 
     #[inline(always)]
     fn as_mut_xyz(&mut self) -> &mut XYZ<f32> {
-        unsafe { &mut *(self as *mut Self as *mut XYZ<f32>) }
+        unsafe { &mut *(self as *mut Self).cast() }
     }
 
     #[inline(always)]
     fn into_xy(self) -> XY<f32> {
         let mut out: MaybeUninit<Align16<XY<f32>>> = MaybeUninit::uninit();
         unsafe {
-            _mm_store_ps(out.as_mut_ptr() as *mut f32, self);
+            _mm_store_ps(out.as_mut_ptr().cast(), self);
             out.assume_init().0
         }
     }
@@ -352,7 +378,7 @@ impl Vector3<f32> for __m128 {
     fn into_array(self) -> [f32; 3] {
         let mut out: MaybeUninit<Align16<[f32; 3]>> = MaybeUninit::uninit();
         unsafe {
-            _mm_store_ps(out.as_mut_ptr() as *mut f32, self);
+            _mm_store_ps(out.as_mut_ptr().cast(), self);
             out.assume_init().0
         }
     }
@@ -366,7 +392,7 @@ impl Vector3<f32> for __m128 {
     fn into_tuple(self) -> (f32, f32, f32) {
         let mut out: MaybeUninit<Align16<(f32, f32, f32)>> = MaybeUninit::uninit();
         unsafe {
-            _mm_store_ps(out.as_mut_ptr() as *mut f32, self);
+            _mm_store_ps(out.as_mut_ptr().cast(), self);
             out.assume_init().0
         }
     }
@@ -493,19 +519,19 @@ impl Vector4<f32> for __m128 {
 
     #[inline(always)]
     fn as_ref_xyzw(&self) -> &XYZW<f32> {
-        unsafe { &*(self as *const Self as *const XYZW<f32>) }
+        unsafe { &*(self as *const Self).cast() }
     }
 
     #[inline(always)]
     fn as_mut_xyzw(&mut self) -> &mut XYZW<f32> {
-        unsafe { &mut *(self as *mut Self as *mut XYZW<f32>) }
+        unsafe { &mut *(self as *mut Self).cast() }
     }
 
     #[inline(always)]
     fn into_xy(self) -> XY<f32> {
         let mut out: MaybeUninit<Align16<XY<f32>>> = MaybeUninit::uninit();
         unsafe {
-            _mm_store_ps(out.as_mut_ptr() as *mut f32, self);
+            _mm_store_ps(out.as_mut_ptr().cast(), self);
             out.assume_init().0
         }
     }
@@ -514,7 +540,7 @@ impl Vector4<f32> for __m128 {
     fn into_xyz(self) -> XYZ<f32> {
         let mut out: MaybeUninit<Align16<XYZ<f32>>> = MaybeUninit::uninit();
         unsafe {
-            _mm_store_ps(out.as_mut_ptr() as *mut f32, self);
+            _mm_store_ps(out.as_mut_ptr().cast(), self);
             out.assume_init().0
         }
     }
@@ -528,7 +554,7 @@ impl Vector4<f32> for __m128 {
     fn into_array(self) -> [f32; 4] {
         let mut out: MaybeUninit<Align16<[f32; 4]>> = MaybeUninit::uninit();
         unsafe {
-            _mm_store_ps(out.as_mut_ptr() as *mut f32, self);
+            _mm_store_ps(out.as_mut_ptr().cast(), self);
             out.assume_init().0
         }
     }
@@ -542,7 +568,7 @@ impl Vector4<f32> for __m128 {
     fn into_tuple(self) -> (f32, f32, f32, f32) {
         let mut out: MaybeUninit<Align16<(f32, f32, f32, f32)>> = MaybeUninit::uninit();
         unsafe {
-            _mm_store_ps(out.as_mut_ptr() as *mut f32, self);
+            _mm_store_ps(out.as_mut_ptr().cast(), self);
             out.assume_init().0
         }
     }
@@ -605,7 +631,7 @@ impl SignedVector3<f32> for __m128 {
 
     #[inline]
     fn signum(self) -> Self {
-        const NEG_ONE: __m128 = const_m128!([-1.0; 4]);
+        const NEG_ONE: __m128 = const_f32x4!([-1.0; 4]);
         let mask = self.cmpge(Self::ZERO);
         let result = Self::select(mask, Self::ONE, NEG_ONE);
         let mask = unsafe { _mm_cmpunord_ps(self, self) };
@@ -674,7 +700,6 @@ impl FloatVector3<f32> for __m128 {
     fn length_recip(self) -> f32 {
         unsafe {
             let dot = dot3_in_x(self, self);
-            // _mm_rsqrt_ps is lower precision
             _mm_cvtss_f32(_mm_div_ps(Self::ONE, _mm_sqrt_ps(dot)))
         }
     }
@@ -682,8 +707,11 @@ impl FloatVector3<f32> for __m128 {
     #[inline]
     fn normalize(self) -> Self {
         unsafe {
-            let dot = Vector3::dot_into_vec(self, self);
-            _mm_div_ps(self, _mm_sqrt_ps(dot))
+            let length = _mm_sqrt_ps(Vector3::dot_into_vec(self, self));
+            #[allow(clippy::let_and_return)]
+            let normalized = _mm_div_ps(self, length);
+            glam_assert!(FloatVector3::is_finite(normalized));
+            normalized
         }
     }
 }
@@ -696,7 +724,7 @@ impl SignedVector4<f32> for __m128 {
 
     #[inline]
     fn signum(self) -> Self {
-        const NEG_ONE: __m128 = const_m128!([-1.0; 4]);
+        const NEG_ONE: __m128 = const_f32x4!([-1.0; 4]);
         let mask = self.cmpge(Self::ZERO);
         let result = Self::select(mask, Self::ONE, NEG_ONE);
         let mask = unsafe { _mm_cmpunord_ps(self, self) };
@@ -765,7 +793,6 @@ impl FloatVector4<f32> for __m128 {
     fn length_recip(self) -> f32 {
         unsafe {
             let dot = dot4_in_x(self, self);
-            // _mm_rsqrt_ps is lower precision
             _mm_cvtss_f32(_mm_div_ps(Self::ONE, _mm_sqrt_ps(dot)))
         }
     }
@@ -774,7 +801,10 @@ impl FloatVector4<f32> for __m128 {
     fn normalize(self) -> Self {
         unsafe {
             let dot = Vector4::dot_into_vec(self, self);
-            _mm_div_ps(self, _mm_sqrt_ps(dot))
+            #[allow(clippy::let_and_return)]
+            let normalized = _mm_div_ps(self, _mm_sqrt_ps(dot));
+            glam_assert!(FloatVector4::is_finite(normalized));
+            normalized
         }
     }
 }
@@ -805,7 +835,7 @@ impl From<__m128> for XYZW<f32> {
     fn from(v: __m128) -> XYZW<f32> {
         let mut out: MaybeUninit<Align16<XYZW<f32>>> = MaybeUninit::uninit();
         unsafe {
-            _mm_store_ps(out.as_mut_ptr() as *mut f32, v);
+            _mm_store_ps(out.as_mut_ptr().cast(), v);
             out.assume_init().0
         }
     }
@@ -816,7 +846,7 @@ impl From<__m128> for XYZ<f32> {
     fn from(v: __m128) -> XYZ<f32> {
         let mut out: MaybeUninit<Align16<XYZ<f32>>> = MaybeUninit::uninit();
         unsafe {
-            _mm_store_ps(out.as_mut_ptr() as *mut f32, v);
+            _mm_store_ps(out.as_mut_ptr().cast(), v);
             out.assume_init().0
         }
     }
@@ -827,7 +857,7 @@ impl From<__m128> for XY<f32> {
     fn from(v: __m128) -> XY<f32> {
         let mut out: MaybeUninit<Align16<XY<f32>>> = MaybeUninit::uninit();
         unsafe {
-            _mm_store_ps(out.as_mut_ptr() as *mut f32, v);
+            _mm_store_ps(out.as_mut_ptr().cast(), v);
             out.assume_init().0
         }
     }
