@@ -6,7 +6,7 @@ use crate::{DMat2, DMat4, DQuat, DVec2, DVec3, EulerRot, Mat2, Mat4, Quat, Vec2,
 #[cfg(not(target_arch = "spirv"))]
 use core::fmt;
 use core::iter::{Product, Sum};
-use core::ops::{Add, AddAssign, Deref, DerefMut, Mul, MulAssign, Sub, SubAssign};
+use core::ops::{Add, AddAssign, Deref, DerefMut, Mul, MulAssign, Neg, Sub, SubAssign};
 
 #[cfg(all(
     target_arch = "x86",
@@ -481,12 +481,6 @@ impl Mat3 {
         self.mul_vec3(other.into()).into()
     }
 
-    #[deprecated(since = "0.18.0", note = "please use `as_dmat3()` instead")]
-    #[inline(always)]
-    pub fn as_f64(&self) -> DMat3 {
-        self.as_dmat3()
-    }
-
     #[inline(always)]
     pub fn as_dmat3(&self) -> DMat3 {
         DMat3::from_cols(
@@ -529,12 +523,6 @@ impl Mat3A {
         Vec3A(self.0.mul_vector(other.0))
     }
 
-    #[deprecated(since = "0.18.0", note = "please use `as_dmat3()` instead")]
-    #[inline(always)]
-    pub fn as_f64(&self) -> DMat3 {
-        self.as_dmat3()
-    }
-
     #[inline(always)]
     pub fn as_dmat3(&self) -> DMat3 {
         DMat3::from_cols(
@@ -574,12 +562,6 @@ define_mat3_struct!(DMat3, InnerF64);
 impl DMat3 {
     impl_mat3_methods!(f64, DVec3, DVec3, DVec2, DQuat, DMat2, DMat4, InnerF64);
 
-    #[deprecated(since = "0.18.0", note = "please use `as_mat3()` instead")]
-    #[inline(always)]
-    pub fn as_f32(&self) -> Mat3 {
-        self.as_mat3()
-    }
-
     #[inline(always)]
     pub fn as_mat3(&self) -> Mat3 {
         Mat3::from_cols(
