@@ -26,7 +26,7 @@ use core::arch::wasm32::v128;
 #[cfg(not(target_arch = "spirv"))]
 use core::fmt;
 use core::iter::{Product, Sum};
-use core::ops::{Add, AddAssign, Deref, DerefMut, Mul, MulAssign, Sub, SubAssign};
+use core::ops::{Add, AddAssign, Deref, DerefMut, Mul, MulAssign, Neg, Sub, SubAssign};
 
 //macro_rules! define_mat4_struct {
 //    ($mat4:ident, $inner:ident) => {
@@ -772,10 +772,19 @@ type InnerF32 = Columns4<XYZW<f32>>;
 /// perspective correction using the [`Self::project_point3()`] convenience method.
 #[derive(Clone, Copy)]
 #[cfg_attr(
-    not(any(feature = "scalar-math", target_arch = "spriv")),
-    repr(align(16))
+    any(
+        not(any(feature = "scalar-math", target_arch = "spriv")),
+        feature = "cuda"
+    ),
+    repr(C, align(16))
+)]
+#[cfg_attr(
+    all(
+        any(feature = "scalar-math", target_arch = "spriv"),
+        not(feature = "cuda"),
+    ),
+    repr(transparent)
 )]
-#[cfg_attr(any(feature = "scalar-math", target_arch = "spriv"), repr(transparent))]
 pub struct Mat4(pub(crate) InnerF32);
 // define_mat4_struct!(Mat4, InnerF32);
 
@@ -800,12 +809,6 @@ impl Mat4 {
         Vec3A(self.0.transform_float4_as_vector3(other.0.into()).into())
     }
 
-    #[deprecated(since = "0.18.0", note = "please use `as_dmat4()` instead")]
-    #[inline(always)]
-    pub fn as_f64(&self) -> DMat4 {
-        self.as_dmat4()
-    }
-
     #[inline(always)]
     pub fn as_dmat4(&self) -> DMat4 {
         DMat4::from_cols(
@@ -850,19 +853,14 @@ type InnerF64 = Columns4<XYZW<f64>>;
 /// The resulting perspective project can be use to transform 3D vectors as points with
 /// perspective correction using the [`Self::project_point3()`] convenience method.
 #[derive(Clone, Copy)]
-#[repr(transparent)]
+#[cfg_attr(not(feature = "cuda"), repr(transparent))]
+#[cfg_attr(feature = "cuda", repr(C, align(16)))]
 pub struct DMat4(pub(crate) InnerF64);
 // define_mat4_struct!(DMat4, InnerF64);
 
 impl DMat4 {
     impl_mat4_methods!(f64, DVec4, DVec3, DMat3, DQuat, InnerF64);
 
-    #[deprecated(since = "0.18.0", note = "please use `as_mat4()` instead")]
-    #[inline(always)]
-    pub fn as_f32(&self) -> Mat4 {
-        self.as_mat4()
-    }
-
     #[inline(always)]
     pub fn as_mat4(&self) -> Mat4 {
         Mat4::from_cols(
@@ -875,24 +873,17 @@ impl DMat4 {
 }
 impl_mat4_traits!(f64, dmat4, DMat4, DVec4);
 
-#[cfg(any(feature = "scalar-math", target_arch = "spriv"))]
 mod const_test_mat4 {
     const_assert_eq!(
-        core::mem::align_of::<f32>(),
+        core::mem::align_of::<super::Vec4>(),
         core::mem::align_of::<super::Mat4>()
     );
     const_assert_eq!(64, core::mem::size_of::<super::Mat4>());
 }
 
-#[cfg(not(any(feature = "scalar-math", target_arch = "spriv")))]
-mod const_test_mat4 {
-    const_assert_eq!(16, core::mem::align_of::<super::Mat4>());
-    const_assert_eq!(64, core::mem::size_of::<super::Mat4>());
-}
-
 mod const_test_dmat4 {
     const_assert_eq!(
-        core::mem::align_of::<f64>(),
+        core::mem::align_of::<super::DVec4>(),
         core::mem::align_of::<super::DMat4>()
     );
     const_assert_eq!(128, core::mem::size_of::<super::DMat4>());
