@@ -3,8 +3,8 @@ use crate::core::traits::{
     vector::{FloatVector4, MaskVector4, Vector, Vector4, Vector4Const},
 };
 use crate::euler::{EulerFromQuaternion, EulerRot, EulerToQuaternion};
-use crate::{DMat3, DMat4, DVec3, DVec4};
-use crate::{Mat3, Mat4, Vec3, Vec3A, Vec4};
+use crate::{DMat3, DMat4, DVec2, DVec3, DVec4};
+use crate::{Mat3, Mat4, Vec2, Vec3, Vec3A, Vec4};
 
 #[cfg(not(feature = "std"))]
 use num_traits::Float;
@@ -22,18 +22,22 @@ use core::arch::x86::*;
 ))]
 use core::arch::x86_64::*;
 
+#[cfg(all(target_feature = "simd128", not(feature = "scalar-math")))]
+use core::arch::wasm32::v128;
+
 #[cfg(not(target_arch = "spirv"))]
 use core::fmt;
+use core::iter::{Product, Sum};
 use core::ops::{Add, Deref, Div, Mul, MulAssign, Neg, Sub};
 
-#[cfg(feature = "std")]
-use std::iter::{Product, Sum};
-
 macro_rules! impl_quat_methods {
-    ($t:ident, $quat:ident, $vec3:ident, $vec4:ident, $mat3:ident, $mat4:ident, $inner:ident) => {
+    ($t:ident, $quat:ident, $vec2:ident, $vec3:ident, $vec4:ident, $mat3:ident, $mat4:ident, $inner:ident) => {
         /// The identity quaternion. Corresponds to no rotation.
         pub const IDENTITY: Self = Self($inner::W);
 
+        /// All NAN:s.
+        pub const NAN: Self = Self(<$inner as crate::core::traits::scalar::NanConstEx>::NAN);
+
         /// Creates a new rotation quaternion.
         ///
         /// This should generally not be called manually unless you know what you are doing.
@@ -85,9 +89,7 @@ macro_rules! impl_quat_methods {
         /// Panics if `slice` length is less than 4.
         #[inline(always)]
         pub fn from_slice(slice: &[$t]) -> Self {
-            #[allow(clippy::let_and_return)]
-            let q = Vector4::from_slice_unaligned(slice);
-            Self(q)
+            Self(Vector4::from_slice_unaligned(slice))
         }
 
         /// Writes the quaternion to an unaligned slice.
@@ -182,20 +184,19 @@ macro_rules! impl_quat_methods {
         /// # Panics
         ///
         /// Will panic if `from` or `to` are not normalized when `glam_assert` is enabled.
-        #[cfg(feature = "std")]
         pub fn from_rotation_arc(from: $vec3, to: $vec3) -> Self {
             glam_assert!(from.is_normalized());
             glam_assert!(to.is_normalized());
 
-            let one_minus_eps = 1.0 - 2.0 * core::$t::EPSILON;
+            const ONE_MINUS_EPS: $t = 1.0 - 2.0 * core::$t::EPSILON;
             let dot = from.dot(to);
-            if dot > one_minus_eps {
+            if dot > ONE_MINUS_EPS {
                 // 0° singulary: from ≈ to
                 Self::IDENTITY
-            } else if dot < -one_minus_eps {
+            } else if dot < -ONE_MINUS_EPS {
                 // 180° singulary: from ≈ -to
-                let pi = core::$t::consts::PI; // half a turn = 𝛕/2 = 180°
-                Self::from_axis_angle(from.any_orthonormal_vector(), pi)
+                use core::$t::consts::PI; // half a turn = 𝛕/2 = 180°
+                Self::from_axis_angle(from.any_orthonormal_vector(), PI)
             } else {
                 let c = from.cross(to);
                 Self::from_xyzw(c.x, c.y, c.z, 1.0 + dot).normalize()
@@ -215,7 +216,6 @@ macro_rules! impl_quat_methods {
         /// # Panics
         ///
         /// Will panic if `from` or `to` are not normalized when `glam_assert` is enabled.
-        #[cfg(feature = "std")]
         pub fn from_rotation_arc_colinear(from: $vec3, to: $vec3) -> Self {
             if from.dot(to) < 0.0 {
                 Self::from_rotation_arc(from, -to)
@@ -224,6 +224,44 @@ macro_rules! impl_quat_methods {
             }
         }
 
+        /// Gets the minimal rotation for transforming `from` to `to`.  The resulting rotation is
+        /// around the z axis. Will rotate at most 180 degrees.
+        ///
+        /// The input vectors must be normalized (unit-length).
+        ///
+        /// `from_rotation_arc_2d(from, to) * from ≈ to`.
+        ///
+        /// For near-singular cases (from≈to and from≈-to) the current implementation
+        /// is only accurate to about 0.001 (for `f32`).
+        ///
+        /// # Panics
+        ///
+        /// Will panic if `from` or `to` are not normalized when `glam_assert` is enabled.
+        pub fn from_rotation_arc_2d(from: $vec2, to: $vec2) -> Self {
+            glam_assert!(from.is_normalized());
+            glam_assert!(to.is_normalized());
+
+            const ONE_MINUS_EPSILON: $t = 1.0 - 2.0 * core::$t::EPSILON;
+            let dot = from.dot(to);
+            if dot > ONE_MINUS_EPSILON {
+                // 0° singulary: from ≈ to
+                Self::IDENTITY
+            } else if dot < -ONE_MINUS_EPSILON {
+                // 180° singulary: from ≈ -to
+                const COS_FRAC_PI_2: $t = 0.0;
+                const SIN_FRAC_PI_2: $t = 1.0;
+                // rotation around z by PI radians
+                Self::from_xyzw(0.0, 0.0, SIN_FRAC_PI_2, COS_FRAC_PI_2)
+            } else {
+                // vector3 cross where z=0
+                let z = from.x * to.y - to.x * from.y;
+                let w = 1.0 + dot;
+                // calculate length with x=0 and y=0 to normalize
+                let len_rcp = 1.0 / (z * z + w * w).sqrt();
+                Self::from_xyzw(0.0, 0.0, z * len_rcp, w * len_rcp)
+            }
+        }
+
         /// Returns the rotation axis and angle (in radians) of `self`.
         #[inline(always)]
         pub fn to_axis_angle(self) -> ($vec3, $t) {
@@ -244,6 +282,12 @@ macro_rules! impl_quat_methods {
             euler.convert_quat(self)
         }
 
+        /// Returns the vector part of the quaternion.
+        #[inline(always)]
+        pub fn xyz(self) -> $vec3 {
+            $vec3::new(self.x, self.y, self.z)
+        }
+
         /// Returns the quaternion conjugate of `self`. For a unit quaternion the
         /// conjugate is also the inverse.
         #[must_use]
@@ -276,7 +320,7 @@ macro_rules! impl_quat_methods {
         }
 
         /// Computes the length of `self`.
-        #[cfg_attr(docsrs, doc(alias = "magnitude"))]
+        #[doc(alias = "magnitude")]
         #[inline(always)]
         pub fn length(self) -> $t {
             FloatVector4::length(self.0)
@@ -286,7 +330,7 @@ macro_rules! impl_quat_methods {
         ///
         /// This is generally faster than `length()` as it avoids a square
         /// root operation.
-        #[cfg_attr(docsrs, doc(alias = "magnitude2"))]
+        #[doc(alias = "magnitude2")]
         #[inline(always)]
         pub fn length_squared(self) -> $t {
             FloatVector4::length_squared(self.0)
@@ -376,7 +420,7 @@ macro_rules! impl_quat_methods {
         ///
         /// Will panic if `self` or `end` are not normalized when `glam_assert` is enabled.
         #[inline(always)]
-        #[cfg_attr(docsrs, doc(alias = "mix"))]
+        #[doc(alias = "mix")]
         pub fn lerp(self, end: Self, s: $t) -> Self {
             Self(self.0.lerp(end.0, s))
         }
@@ -440,7 +484,7 @@ macro_rules! impl_quat_traits {
 
         #[cfg(not(target_arch = "spirv"))]
         impl fmt::Debug for $quat {
-            fn fmt(&self, fmt: &mut fmt::Formatter) -> fmt::Result {
+            fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
                 fmt.debug_tuple(stringify!($quat))
                     .field(&self.x)
                     .field(&self.y)
@@ -452,7 +496,7 @@ macro_rules! impl_quat_traits {
 
         #[cfg(not(target_arch = "spirv"))]
         impl fmt::Display for $quat {
-            fn fmt(&self, fmt: &mut fmt::Formatter) -> fmt::Result {
+            fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
                 write!(fmt, "[{}, {}, {}, {}]", self.x, self.y, self.z, self.w)
             }
         }
@@ -624,7 +668,6 @@ macro_rules! impl_quat_traits {
             }
         }
 
-        #[cfg(feature = "std")]
         impl<'a> Sum<&'a Self> for $quat {
             fn sum<I>(iter: I) -> Self
             where
@@ -635,7 +678,6 @@ macro_rules! impl_quat_traits {
             }
         }
 
-        #[cfg(feature = "std")]
         impl<'a> Product<&'a Self> for $quat {
             fn product<I>(iter: I) -> Self
             where
@@ -650,7 +692,13 @@ macro_rules! impl_quat_traits {
 #[cfg(all(target_feature = "sse2", not(feature = "scalar-math")))]
 type InnerF32 = __m128;
 
-#[cfg(any(not(target_feature = "sse2"), feature = "scalar-math"))]
+#[cfg(all(target_feature = "simd128", not(feature = "scalar-math")))]
+type InnerF32 = v128;
+
+#[cfg(any(
+    not(any(target_feature = "sse2", target_feature = "simd128")),
+    feature = "scalar-math"
+))]
 type InnerF32 = crate::XYZW<f32>;
 
 /// A quaternion representing an orientation.
@@ -662,14 +710,27 @@ type InnerF32 = crate::XYZW<f32>;
 /// This type is 16 byte aligned.
 #[derive(Clone, Copy)]
 #[cfg_attr(
-    not(any(feature = "scalar-math", target_arch = "spriv")),
-    repr(align(16))
+    not(any(
+        feature = "scalar-math",
+        target_arch = "spriv",
+        target_feature = "sse2",
+        target_feature = "simd128"
+    )),
+    repr(C, align(16))
+)]
+#[cfg_attr(
+    any(
+        feature = "scalar-math",
+        target_arch = "spriv",
+        target_feature = "sse2",
+        target_feature = "simd128"
+    ),
+    repr(transparent)
 )]
-#[cfg_attr(any(feature = "scalar-math", target_arch = "spriv"), repr(transparent))]
 pub struct Quat(pub(crate) InnerF32);
 
 impl Quat {
-    impl_quat_methods!(f32, Quat, Vec3, Vec4, Mat3, Mat4, InnerF32);
+    impl_quat_methods!(f32, Quat, Vec2, Vec3, Vec4, Mat3, Mat4, InnerF32);
 
     /// Multiplies a quaternion and a 3D vector, returning the rotated vector.
     #[inline(always)]
@@ -715,7 +776,7 @@ type InnerF64 = crate::XYZW<f64>;
 pub struct DQuat(pub(crate) InnerF64);
 
 impl DQuat {
-    impl_quat_methods!(f64, DQuat, DVec3, DVec4, DMat3, DMat4, InnerF64);
+    impl_quat_methods!(f64, DQuat, DVec2, DVec3, DVec4, DMat3, DMat4, InnerF64);
 
     #[inline(always)]
     pub fn as_f32(self) -> Quat {
